@@ -1,10 +1,12 @@
-// Copyright 2014, 2015, 2016 Simon Lydell
-// X11 (“MIT”) Licensed. (See LICENSE.)
+// Copyright 2014, 2015, 2016, 2017, 2018 Simon Lydell
+// License: MIT. (See LICENSE.)
 
-var fs       = require("fs")
-var util     = require("util")
-var assert   = require("assert")
-var jsTokens = require("../")
+var fs           = require("fs")
+var util         = require("util")
+var assert       = require("assert")
+var jsTokensTmp  = require("../")
+var jsTokens     = jsTokensTmp.default
+var matchToToken = jsTokensTmp.matchToToken
 
 
 suite("jsTokens", function() {
@@ -16,10 +18,10 @@ suite("jsTokens", function() {
 })
 
 
-suite("jsTokens.matchToToken", function() {
+suite("matchToToken", function() {
 
   test("is a function", function() {
-    assert.equal(typeof jsTokens.matchToToken, "function")
+    assert.equal(typeof matchToToken, "function")
   })
 
 })
@@ -38,9 +40,9 @@ suite("tokens", function() {
       expected = undefined
     }
     jsTokens.lastIndex = 0
-    var token = jsTokens.matchToToken(jsTokens.exec(string))
+    var token = matchToToken(jsTokens.exec(string))
 
-    test(string, function() {
+    test(String(string), function() {
       if (expected === false) {
         assert.notEqual(token.type, type)
       } else {
@@ -80,7 +82,6 @@ suite("tokens", function() {
 
     match("\u00a0")
     match("\u1680")
-    match("\u180e")
     match("\u2000")
     match("\u2001")
     match("\u2002")
@@ -161,6 +162,12 @@ suite("tokens", function() {
     match("'\\\r'")
     match('"\\\r"')
     match("`\\\r`")
+    match("'\u2028'")
+    match('"\u2028"')
+    match("`\u2028`")
+    match("'\u2029'")
+    match('"\u2029"')
+    match("`\u2029`")
     match("'\\\u2028'")
     match('"\\\u2028"')
     match("`\\\u2028`")
@@ -192,11 +199,11 @@ suite("tokens", function() {
     match("'\r", "'", {closed: false})
     match('"\r', '"', {closed: false})
     match("`\r", {closed: false})
-    match("'\u2028", "'", {closed: false})
-    match('"\u2028', '"', {closed: false})
+    match("'\u2028", {closed: false})
+    match('"\u2028', {closed: false})
     match("`\u2028", {closed: false})
-    match("'\u2029", "'", {closed: false})
-    match('"\u2029', '"', {closed: false})
+    match("'\u2029", {closed: false})
+    match('"\u2029', {closed: false})
     match("`\u2029", {closed: false})
     match("'\r\n", "'", {closed: false})
     match('"\r\n', '"', {closed: false})
@@ -264,7 +271,8 @@ suite("tokens", function() {
     match("/a/i")
     match("/a/y")
     match("/a/u")
-    match("/a/gmiyu")
+    match("/a/s")
+    match("/a/gmiyus")
     match("/a/myg")
     match("/a/e", false)
     match("/a/invalidFlags", false)
@@ -586,7 +594,6 @@ suite("tokens", function() {
 
     match("a\u00a0", "a")
     match("a\u1680", "a")
-    match("a\u180e", "a")
     match("a\u2000", "a")
     match("a\u2001", "a")
     match("a\u2002", "a")
@@ -617,7 +624,8 @@ suite("tokens", function() {
     match("\\u{0123}")
     match("\\u{01234}")
     match("\\u{012345}")
-    match("\\u{0123456}", false)
+    match("\\u{0123456}")
+    match("\\u{00000000000000a0}")
     match("\\u{15cF}")
     match("\\u{15cG}", false)
     match("a\\u{0000}b")
